@@ -54,7 +54,7 @@
         </tr>
         <tr>
           <td>Operating Systems:</td>
-          <td>Linux 2.6, FreeBSD 6.0, OpenBSD 3.8</td>
+          <td>Linux 2.4/2.6, FreeBSD 6.0, OpenBSD 3.8</td>
         </tr>
         <tr>
           <td>Programming Language:</td>
