@@ -51,8 +51,8 @@
 
       <div class="indent">
         <p class="code"><tt>
-        $ <b>cd /usr/src/linux-2.6.13/;</b><br />
-        $ <b>patch -p1 -i /usr/src/ttyrpld/kpatch/linux-2.6.13.diff;</b><br />
+        $ <b>cd /usr/src/linux-2.6.15/;</b><br />
+        $ <b>patch -p1 -i /usr/src/ttyrpld/kpatch/linux-2.6.15.diff;</b><br />
         $ <b>make menuconfig;</b>
         </tt></p>
       </div>
@@ -61,6 +61,9 @@
       suits your needs to choose "<tt>TTY logging via rpldev</tt>" in the
       "<tt>Security options</tt>" menu.</p>
 
+      <p class="block"><i>Note: For Linux Kernels 2.4.x, the "TTY logging via
+      rpldev" option is available in the "Character devices" menu.</p>
+
     </td>
   </tr>
   <tr>
