@@ -1,7 +1,7 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 freebsd-5.3/rpldev.c - Kernel interface for RPLD
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2005
+  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2006
   -- License restrictions apply (GPL v2)
 
   This file is part of ttyrpld.
@@ -280,7 +280,8 @@ static int urpl_read(struct cdev *cd, struct uio *uio, int flags) {
     mtx_lock(&Buffer_lock);
     while(BufRP == BufWP) {
         mtx_unlock(&Buffer_lock);
-        if(flags & IO_NDELAY) { return EWOULDBLOCK; }
+        if(flags & IO_NDELAY)
+            return EWOULDBLOCK;
         if((eax = tsleep(&Buffer, PCATCH, "rpldev", 0)) != 0)
             return eax;
         mtx_lock(&Buffer_lock);
