@@ -1,7 +1,7 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 kernel/rpldev.c - Kernel interface for RPLD
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2005
+  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2006
   -- License restrictions apply (GPL v2)
 
   This file is part of ttyrpld.
@@ -50,12 +50,22 @@ kernel/rpldev.c - Kernel interface for RPLD
 #define PREFIX "rpldev: "
 #define MAXFNLEN 256
 
-#define IS_PTY_MASTER(tty) \
-    ((tty)->driver->major == UNIX98_PTY_MASTER_MAJOR || \
-        (tty)->driver->major == PTY_MASTER_MAJOR)
-#define TTY_DEVNR(tty) \
-    cpu_to_le32(mkdev_26(tty->driver->major, \
-        tty->driver->minor_start + tty->index))
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 0)
+#    define KERNEL_2_4 1
+#    define IS_PTY_MASTER(tty) \
+      (((tty)->driver.major >= UNIX98_PTY_MASTER_MAJOR && \
+      (tty)->driver.major < UNIX98_PTY_MASTER_MAJOR + \
+      UNIX98_PTY_MAJOR_COUNT) || (tty)->driver.major == PTY_MASTER_MAJOR)
+#    define TTY_DEVNR(tty) \
+      cpu_to_le32(mkdev_26(MAJOR(tty->device), MINOR(tty->device)))
+#else
+#    define IS_PTY_MASTER(tty) \
+      ((tty)->driver->major == UNIX98_PTY_MASTER_MAJOR || \
+      (tty)->driver->major == PTY_MASTER_MAJOR)
+#    define TTY_DEVNR(tty) \
+      cpu_to_le32(mkdev_26(tty->driver->major, \
+      tty->driver->minor_start + tty->index))
+#endif
 #ifndef SEEK_SET
 #    define SEEK_SET 0
 #endif
@@ -125,8 +135,14 @@ MODULE_AUTHOR("Jan Engelhardt <jengelh [at] linux01 gwdg de>");
 MODULE_LICENSE("GPL v2");
 MODULE_PARM_DESC(Bufsize, "Buffer size (default 32K)");
 MODULE_PARM_DESC(Minor_nr, "Minor number to use (default: 255(=DYNAMIC))");
+#ifdef KERNEL_2_4
+MODULE_PARM(Bufsize, "i");
+MODULE_PARM(Minor_nr, "i");
+EXPORT_NO_SYMBOLS;
+#else
 module_param(Bufsize, uint, S_IRUGO);
 module_param(Minor_nr, int, S_IRUGO);
+#endif
 
 //-----------------------------------------------------------------------------
 __init extern int init_module(void) {
@@ -319,7 +335,6 @@ static int urpl_open(struct inode *inode, struct file *filp) {
     Buffer = __vmalloc(Bufsize, GFP_KERNEL | __GFP_HIGHMEM, PAGE_KERNEL);
     if(Buffer == NULL) {
         up(&Buffer_lock);
-        up(&Open_lock);
         return -ENOMEM;
     }
     BufRP = BufWP = Buffer;
