@@ -1,7 +1,7 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 user/rpld.c - User space daemon (filtering, etc.)
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2005
+  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2006
   Copyright © Nguyen Anh Quynh <aquynh [at] gmail com>, 2005
   -- License restrictions apply (GPL v2)
 
@@ -191,7 +191,7 @@ static void mainloop(int fd) {
                 fprintf(stderr, _("\n" "Short read: %ld bytes only. "
                  "Error %d: %s\n"), (long)eax, errno, strerror(errno));
             }
-//            Opt._running = 0;
+            Opt._running = 0;
             break;
         }
 
